package org.assertj.core.api.iterable;

/**
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2015 the original author or authors.
 */

import static org.assertj.core.api.Assertions.assertThat;
import static org.assertj.core.api.Assertions.failBecauseExceptionWasNotThrown;

import org.assertj.core.util.introspection.IntrospectionError;
import org.junit.Test;

public class IterableAssert_filteredOnNull_Test extends IterableAssert_filtered_baseTest {

  @Test
  public void should_filter_iterable_under_test_on_null_property_values() {
    assertThat(employees).filteredOnNull("name").containsOnly(noname);
  }

  @Test
  public void should_filter_iterable_under_test_on_null_nested_property_values() {
    assertThat(employees).filteredOnNull("name.last").containsOnly(yoda, obiwan, noname);
  }

  @Test
  public void should_fail_if_on_of_the_iterable_element_does_not_have_given_property_or_field() {
    try {
      assertThat(employees).filteredOnNull("secret");
      failBecauseExceptionWasNotThrown(IntrospectionError.class);
    } catch (IntrospectionError e) {
      assertThat(e).hasMessageContaining("Can't find any field or property with name 'secret'");
    }
  }

}
